@@ -15,4 +15,4 @@ fi
 # Extract strings from all source files.
 # If your framework depends on KI18n, use $XGETTEXT. If it uses Qt translation
 # system, use $EXTRACT_TR_STRINGS.
-$XGETTEXT `find . -name \*.cpp -o -name \*.h -name \*.qml` -o $podir/kross5.pot
+$XGETTEXT `find . -name \*.cpp -o -name \*.h -o -name \*.qml` -o $podir/kross5.pot
